@@ -46,8 +46,10 @@ from pyspark.sql.functions import expr as sql_
 from pyspark.sql.types import *
 from termcolor import colored
 
-sys.path.insert(0, ".")
+if '.' not in sys.path and './' not in sys.path: 
+    sys.path.insert(0, ".")
 def f2_download(url):
+    g = globals()
     def download(filepath):
         file_uri = f"{url}/{filepath}"
         filename = filepath.split("/")[-1]
@@ -55,6 +57,7 @@ def f2_download(url):
         with open(f"./{filename}", 'w') as fw:
             with urllib2.urlopen(file_uri) as f:
                 fw.write(f.read().decode())
-        if module_name in globals():
-            importlib.reload(globals()[module_name])
-    return download
+        g[module_name] = __import__(module_name)
+        if module_name in g:
+            importlib.reload(g[module_name])
+    return download
\ No newline at end of file
